@@ -1,11 +1,11 @@
-import pyzmq
+import zmq
 from threading import Thread, Event
 import json
 import pandas as pd
 import os
 from time import sleep
 
-versionNo = "1.0.0"
+versionNo = "1.0.1"
 
 controlEndpoint = "tcp://127.0.0.1:5557"
 dataEndpoint = "tcp://127.0.0.1:5556"
@@ -17,7 +17,7 @@ profilesPath = profilesPath.replace("\\","/")
 decimalVals = {
     'temperatureMeasured': 6,
     'temperatureSetpoint': 6,
-    'powerMeasured': 3,
+    'powerMeasured': 8,
     'currentMeasured': 18,
     'voltageMeasured': 15,
     'setpoint': 18,
@@ -56,12 +56,12 @@ def createControlMessage(details):
 
 def sendControl(controlDict):  
     controlString = createControlMessage(controlDict)
-    context = pyzmq.Context()
-    controlSock = context.socket(pyzmq.REQ)
+    context = zmq.Context()
+    controlSock = context.socket(zmq.REQ)
     controlSock.connect(controlEndpoint)
     controlSock.send(controlString)
     returnMessage = controlSock.recv_json()
-    controlSock.setsockopt(pyzmq.LINGER, 0)
+    controlSock.setsockopt(zmq.LINGER, 0)
     controlSock.close()
     context.term()
     if returnMessage["resultCode"] != "ok":
@@ -343,26 +343,28 @@ class eventHandler():
         self.eventSock = None
 
     def subscribe(self):
-        self.context = pyzmq.Context()
-        self.eventSock = self.context.socket(pyzmq.SUB)
+        self.context = zmq.Context()
+        self.eventSock = self.context.socket(zmq.SUB)
         self.eventSock.connect(dataEndpoint)
         btopic = bytes('event', 'utf_8')
-        self.eventSock.setsockopt(pyzmq.SUBSCRIBE, btopic)
+        self.eventSock.setsockopt(zmq.SUBSCRIBE, btopic)
         self.eventCatcherThread = Thread(target=self.eventCatcher)
         self.eventCatcherThread.start()
 
     def eventCatcher(self):
         print("Subscribed to impulse events. ")
+        print()
         sleep(0.01)
         while True:
             if self.event.is_set():
                 break
             try:
                 [address, contents] = self.eventSock.recv_multipart()
-            except:
-                continue
-            else:
                 contents = json.loads(contents)
+            except:
+                print("Multipart issue")
+                continue
+            else:   
                 self.lastMssg = contents
                 if contents["$type"]=="data.event.stimulusActionFinished":
                     if contents["stimulusType"]=="heat":
@@ -380,7 +382,7 @@ class eventHandler():
                     sleep(0.1)
                 else:
                     print("[IMPULSE EVENT]:",contents)
-        self.eventSock.setsockopt(pyzmq.LINGER, 0)
+        self.eventSock.setsockopt(zmq.LINGER, 0)
         self.eventSock.close()
         self.context.term()
         self.eventSock = None # For jupyter notebook if a cell is rerun
@@ -404,11 +406,11 @@ class dataHandler():
         self.event = Event()
 
     def subscribe(self):
-        self.context = pyzmq.Context()
-        self.dataSock = self.context.socket(pyzmq.SUB)
+        self.context = zmq.Context()
+        self.dataSock = self.context.socket(zmq.SUB)
         self.dataSock.connect(dataEndpoint)
         btopic = bytes(self.topic, 'utf_8')
-        self.dataSock.setsockopt(pyzmq.SUBSCRIBE, btopic)
+        self.dataSock.setsockopt(zmq.SUBSCRIBE, btopic)
         self.dataThread = Thread(target=self.incomingDataReader)
         self.dataThread.start()
         print(f"Subscribed to {self.topic} data. ")
@@ -420,10 +422,10 @@ class dataHandler():
                     break
                 try:
                     [address, contents] = self.dataSock.recv_multipart()
+                    contents = json.loads(contents)
                 except:
                     continue
                 else:
-                    contents = json.loads(contents)
                     contents["flags"]=self.currentFlag
                     self.lastMssg = contents
                     if self.header is None:
@@ -436,10 +438,10 @@ class dataHandler():
                     break
                 try:
                     [address, contents] = self.dataSock.recv_multipart()
+                    contents = json.loads(contents)
                 except:
                     continue
                 else:
-                    contents = json.loads(contents)
                     for channel in contents["channels"]:
                        contents[channel["name"]]=channel["measuredValue"]
                     del contents["channels"]
@@ -449,7 +451,8 @@ class dataHandler():
                         self.header = list(contents.keys())
                         self.data = pd.DataFrame(columns=self.header)
                     self.data = self.data.append(contents, ignore_index=True, sort=False)
-        self.dataSock.setsockopt(pyzmq.LINGER, 0)
+
+        self.dataSock.setsockopt(zmq.LINGER, 0)
         self.dataSock.close()
         self.context.term()
         self.event.clear()
